@@ -438,7 +438,7 @@ TQString AmarokConfigDialog::externalBrowser() const
                  m_opt1->kComboBox_browser->currentText() == i18n( "Default Browser" ) ?
                  "open" :
 #else
-                 m_opt1->kComboBox_browser->currentText() == i18n( "Default KDE Browser" ) ?
+                 m_opt1->kComboBox_browser->currentText() == i18n( "Default TDE Browser" ) ?
                  "kfmclient openURL" :
 #endif
                  m_opt1->kComboBox_browser->currentText().lower() :
