@@ -18,26 +18,26 @@
 #include <tqlayout.h>
 #include <tqregexp.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kcombobox.h>
 #include <kcursor.h> //waiting cursor
 #include <kdialog.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
-#include <kio/job.h>
-#include <kio/jobclasses.h>
+#include <tdefiledialog.h>
+#include <tdeio/job.h>
+#include <tdeio/jobclasses.h>
 #include <klineedit.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <kpushbutton.h>
-#include <kwin.h>
+#include <twin.h>
 
 
 void
 Amarok::coverContextMenu( TQWidget *parent, TQPoint point, const TQString &artist, const TQString &album, bool showCoverManager )
 {
-        KPopupMenu menu;
+        TDEPopupMenu menu;
         enum { SHOW, FETCH, CUSTOM, DELETE, MANAGER };
 
         menu.insertTitle( i18n( "Cover Image" ) );
@@ -234,8 +234,8 @@ CoverFetcher::startFetch()
         + "&SearchIndex=Music&ResponseGroup=Small,Images";
     debug() << url << endl;
 
-    KIO::TransferJob* job = KIO::storedGet( url, false, false );
-    connect( job, TQT_SIGNAL(result( KIO::Job* )), TQT_SLOT(finishedXmlFetch( KIO::Job* )) );
+    TDEIO::TransferJob* job = TDEIO::storedGet( url, false, false );
+    connect( job, TQT_SIGNAL(result( TDEIO::Job* )), TQT_SLOT(finishedXmlFetch( TDEIO::Job* )) );
 
     Amarok::StatusBar::instance()->newProgressOperation( job );
 }
@@ -246,7 +246,7 @@ CoverFetcher::startFetch()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 void
-CoverFetcher::finishedXmlFetch( KIO::Job *job ) //SLOT
+CoverFetcher::finishedXmlFetch( TDEIO::Job *job ) //SLOT
 {
     DEBUG_BLOCK
 
@@ -257,7 +257,7 @@ CoverFetcher::finishedXmlFetch( KIO::Job *job ) //SLOT
         return;
     }
     if ( job ) {
-        KIO::StoredTransferJob* const storedJob = static_cast<KIO::StoredTransferJob*>( job );
+        TDEIO::StoredTransferJob* const storedJob = static_cast<TDEIO::StoredTransferJob*>( job );
         m_xml = TQString::fromUtf8( storedJob->data().data(), storedJob->data().size() );
     }
 
@@ -370,10 +370,10 @@ void CoverFetcher::parseItemNode( const TQDomNode &node )
 }
 
 void
-CoverFetcher::finishedImageFetch( KIO::Job *job ) //SLOT
+CoverFetcher::finishedImageFetch( TDEIO::Job *job ) //SLOT
 {
     if( job->error() ) {
-        debug() << "finishedImageFetch(): KIO::error(): " << job->error() << endl;
+        debug() << "finishedImageFetch(): TDEIO::error(): " << job->error() << endl;
 
         m_errors += i18n("The cover could not be retrieved.");
 
@@ -381,7 +381,7 @@ CoverFetcher::finishedImageFetch( KIO::Job *job ) //SLOT
         return;
     }
 
-    m_image.loadFromData( static_cast<KIO::StoredTransferJob*>( job )->data() );
+    m_image.loadFromData( static_cast<TDEIO::StoredTransferJob*>( job )->data() );
 
     if( m_image.width() <= 1 ) {
         //Amazon seems to offer images of size 1x1 sometimes
@@ -410,8 +410,8 @@ CoverFetcher::attemptAnotherFetch()
         // Amazon suggested some more cover URLs to try before we
         // try a different query
 
-        KIO::TransferJob* job = KIO::storedGet( KURL(m_coverUrls.front()), false, false );
-        connect( job, TQT_SIGNAL(result( KIO::Job* )), TQT_SLOT(finishedImageFetch( KIO::Job* )) );
+        TDEIO::TransferJob* job = TDEIO::storedGet( KURL(m_coverUrls.front()), false, false );
+        connect( job, TQT_SIGNAL(result( TDEIO::Job* )), TQT_SLOT(finishedImageFetch( TDEIO::Job* )) );
 
         Amarok::StatusBar::instance()->newProgressOperation( job );
 
@@ -662,10 +662,10 @@ CoverFetcher::finish()
 }
 
 void
-CoverFetcher::finishWithError( const TQString &message, KIO::Job *job )
+CoverFetcher::finishWithError( const TQString &message, TDEIO::Job *job )
 {
     if( job )
-        warning() << message << " KIO::error(): " << job->errorText() << endl;
+        warning() << message << " TDEIO::error(): " << job->errorText() << endl;
 
     m_errors += message;
     m_success = false;
