@@ -144,7 +144,7 @@ class MediaQueue : public TDEListView, public DropProxyTarget
         void syncPlaylist( const TQString &playlistName, const TQString &sql, bool loading=false );
         void syncPlaylist( const TQString &playlistName, const KURL &url, bool loading=false );
         void addURL( const KURL& url, MetaBundle *bundle=NULL, const TQString &playlistName=TQString() );
-        void addURL( const KURL& url, MediaItem *item );
+        LIBAMAROK_EXPORT void addURL( const KURL& url, MediaItem *item );
         void addURLs( const KURL::List urls, const TQString &playlistName=TQString() );
 
         void URLsAdded(); // call after finishing adding single urls
@@ -169,10 +169,10 @@ class MediaQueue : public TDEListView, public DropProxyTarget
 };
 
 
-class MediaBrowser : public TQVBox
+class LIBAMAROK_EXPORT MediaBrowser : public TQVBox
 {
     Q_OBJECT
-  
+
     friend class DeviceConfigureDialog;
     friend class MediaDevice;
     friend class MediaView;
@@ -184,8 +184,8 @@ class MediaBrowser : public TQVBox
         enum { CONNECT, DISCONNECT, TRANSFER, CONFIGURE, CUSTOM };
 
         static bool isAvailable();
-        LIBAMAROK_EXPORT static MediaBrowser *instance() { return s_instance; }
-        LIBAMAROK_EXPORT static MediaQueue *queue() { return s_instance ? s_instance->m_queue : 0; }
+        static MediaBrowser *instance() { return s_instance; }
+        static MediaQueue *queue() { return s_instance ? s_instance->m_queue : 0; }
 
         MediaBrowser( const char *name );
         virtual ~MediaBrowser();
@@ -244,7 +244,7 @@ class MediaBrowser : public TQVBox
 
         KLineEdit* m_searchEdit;
         TQTimer *m_timer;
-        LIBAMAROK_EXPORT static MediaBrowser *s_instance;
+        static MediaBrowser *s_instance;
 
         TQValueList<MediaDevice *> m_devices;
         TQValueList<MediaDevice *>::iterator m_currentDevice;
@@ -280,7 +280,7 @@ class MediaBrowser : public TQVBox
 class MediaView : public TDEListView
 {
     Q_OBJECT
-  
+
     friend class MediaBrowser;
     friend class MediaDevice;
 
@@ -295,7 +295,7 @@ class MediaView : public TDEListView
         MediaView( TQWidget *parent, MediaDevice *device );
         virtual ~MediaView();
         LIBAMAROK_EXPORT KURL::List nodeBuildDragList( MediaItem* item, int flags=OnlySelected );
-        int getSelectedLeaves(MediaItem *parent, TQPtrList<MediaItem> *list, int flags=OnlySelected );
+        LIBAMAROK_EXPORT int getSelectedLeaves(MediaItem *parent, TQPtrList<MediaItem> *list, int flags=OnlySelected );
         LIBAMAROK_EXPORT MediaItem *newDirectory( MediaItem* parent );
         bool setFilter( const TQString &filter, MediaItem *parent=NULL );
 
@@ -328,7 +328,7 @@ class MediaView : public TDEListView
 class LIBAMAROK_EXPORT MediaDevice : public TQObject, public Amarok::Plugin
 {
     Q_OBJECT
-  
+
     friend class DeviceConfigureDialog;
     friend class TransferDialog;
     friend class MediaBrowser;
