@@ -42,12 +42,12 @@
 #include <klineedit.h>
 #include <knuminput.h>
 #include <kpassdlg.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kresolver.h>
 #include <kstandarddirs.h>     //loading icons
-#include <ktempfile.h>
-#include <ktoolbar.h>
-#include <ktoolbarbutton.h>
+#include <tdetempfile.h>
+#include <tdetoolbar.h>
+#include <tdetoolbarbutton.h>
 
 #if DNSSD_SUPPORT
     #include <dnssd/remoteservice.h>
@@ -80,13 +80,13 @@ DEBUG_BLOCK
     m_customButton       = true;
     m_transfer           = false;
 
-    KToolBar       *toolbar         = MediaBrowser::instance()->getToolBar();
-    KToolBarButton *customButton    = toolbar->getButton( MediaBrowser::CUSTOM );
+    TDEToolBar       *toolbar         = MediaBrowser::instance()->getToolBar();
+    TDEToolBarButton *customButton    = toolbar->getButton( MediaBrowser::CUSTOM );
     customButton->setText( i18n("Add computer") );
 
     toolbar = CollectionBrowser::instance()->getToolBar();
-    toolbar->setIconText( KToolBar::IconTextRight, false );
-    m_broadcastButton = new KToolBarButton( "connect_creating", 0, toolbar, "broadcast_button",
+    toolbar->setIconText( TDEToolBar::IconTextRight, false );
+    m_broadcastButton = new TDEToolBarButton( "connect_creating", 0, toolbar, "broadcast_button",
                                                           i18n("Share My Music") );
     m_broadcastButton->setToggle( true );
 
@@ -112,7 +112,7 @@ DaapClient::isConnected()
 }
 
 bool
-DaapClient::getCapacity(  KIO::filesize_t* /* total */, KIO::filesize_t* /* available */ )
+DaapClient::getCapacity(  TDEIO::filesize_t* /* total */, TDEIO::filesize_t* /* available */ )
 {
     return false;
 }
@@ -236,7 +236,7 @@ DaapClient::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int )
 
     KURL::List urls;
 
-    KPopupMenu menu( m_view );
+    TDEPopupMenu menu( m_view );
     switch( item->type() )
     {
         case MediaItem::DIRECTORY:
@@ -472,7 +472,7 @@ DaapClient::customClicked()
                 : KDialogBase( parent, "DaapAddHostDialog", true, i18n( "Add Computer" ) , Ok|Cancel)
             {
                 m_base = new AddHostBase( this, "DaapAddHostBase" );
-                m_base->m_downloadPixmap->setPixmap( TQPixmap( KGlobal::iconLoader()->iconPath( Amarok::icon( "download" ), -KIcon::SizeEnormous ) ) );
+                m_base->m_downloadPixmap->setPixmap( TQPixmap( TDEGlobal::iconLoader()->iconPath( Amarok::icon( "download" ), -TDEIcon::SizeEnormous ) ) );
                 m_base->m_hostName->setFocus();
                 setMainWidget( m_base );
             }
@@ -523,7 +523,7 @@ DaapClient::passwordPrompt()
                 setButtonOK( ok );
 
                 TQLabel* passIcon = new TQLabel( mainWidget(), "passicon" );
-                passIcon->setPixmap( TQPixmap( KGlobal::iconLoader()->iconPath( "password", -KIcon::SizeHuge ) ) );
+                passIcon->setPixmap( TQPixmap( TDEGlobal::iconLoader()->iconPath( "password", -TDEIcon::SizeHuge ) ) );
                 TQHBox* loginArea = new TQHBox( mainWidget(), "passhbox" );
                 new TQLabel( i18n( "Password:"), loginArea, "passlabel" );
                 m_input = new KPasswordEdit( loginArea, "passedit" );
