@@ -3,7 +3,7 @@
  *                       (C) 2005 Jeff Mitchell <kde-dev@emailgoeshere.com> *
  *                       (C) 2005 Seb Ruiz <me@sebruiz.net>                 *
  *                                                                          *
- * With some code helpers from KIO_VFAT                                     *
+ * With some code helpers from TDEIO_VFAT                                     *
  *                        (c) 2004 Thomas Loeber <vfat@loeber1.de>          *
  ***************************************************************************/
 
@@ -36,16 +36,16 @@ AMAROK_EXPORT_PLUGIN( GenericMediaDevice )
 #include "transferdialog.h"
 #include "genericmediadeviceconfigdialog.h"
 
-#include <kapplication.h>
-#include <kconfig.h>           //download saveLocation
+#include <tdeapplication.h>
+#include <tdeconfig.h>           //download saveLocation
 #include <kdiskfreesp.h>
 #include <kiconloader.h>       //smallIcon
-#include <kio/job.h>
-#include <kio/jobclasses.h>
-#include <kio/netaccess.h>
-#include <kmessagebox.h>
+#include <tdeio/job.h>
+#include <tdeio/jobclasses.h>
+#include <tdeio/netaccess.h>
+#include <tdemessagebox.h>
 #include <kmountpoint.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kurlrequester.h>     //downloadSelectedItems()
 #include <kurlrequesterdlg.h>  //downloadSelectedItems()
 
@@ -440,7 +440,7 @@ GenericMediaDevice::renameItem( TQListViewItem *item ) // SLOT
     debug() << "Renaming: " << src << " to: " << dst << endl;
 
     //do we want a progress dialog?  If so, set last false to true
-    if( KIO::NetAccess::file_move( KURL::fromPathOrURL(src), KURL::fromPathOrURL(dst), -1, false, false, false ) )
+    if( TDEIO::NetAccess::file_move( KURL::fromPathOrURL(src), KURL::fromPathOrURL(dst), -1, false, false, 0 ) )
     {
         m_mfm.erase( m_mim[item]->getFullName() );
         m_mim[item]->setNamesFromBase( item->text(0) );
@@ -476,7 +476,7 @@ GenericMediaDevice::newDirectory( const TQString &name, MediaItem *parent )
     debug() << "Creating directory: " << fullPath << endl;    
     const KURL url( fullPath );
 
-    if( !KIO::NetAccess::mkdir( url, m_parent ) ) //failed
+    if( !TDEIO::NetAccess::mkdir( url, m_parent ) ) //failed
     {
         debug() << "Failed to create directory " << fullPath << endl;
         return 0;
@@ -516,7 +516,7 @@ GenericMediaDevice::addToDirectory( MediaItem *directory, TQPtrList<MediaItem> i
         const KURL srcurl(src);
         const KURL dsturl(dst);
 
-        if ( !KIO::NetAccess::file_move( srcurl, dsturl, -1, false, false, m_parent ) )
+        if ( !TDEIO::NetAccess::file_move( srcurl, dsturl, -1, false, false, m_parent ) )
             debug() << "Failed moving " << src << " to " << dst << endl;
         else
         {
@@ -597,10 +597,10 @@ GenericMediaDevice::checkAndBuildLocation( const TQString& location )
         TQString secondpart = cleanPath( location.section( '/', i, i ) );
         KURL url = KURL::fromPathOrURL( firstpart + '/' + secondpart );
 
-        if( !KIO::NetAccess::exists( url, false, m_parent ) )
+        if( !TDEIO::NetAccess::exists( url, false, m_parent ) )
         {
             debug() << "directory does not exist, creating..." << url << endl;
-            if( !KIO::NetAccess::mkdir(url, m_view ) ) //failed
+            if( !TDEIO::NetAccess::mkdir(url, m_view ) ) //failed
             {
                 debug() << "Failed to create directory " << url << endl;
                 return;
@@ -735,7 +735,7 @@ GenericMediaDevice::deleteItemFromDevice( MediaItem *item, int /*flags*/ )
     TQString path = m_mim[item]->getFullName();
     debug() << "Deleting path: " << path << endl;
 
-    if ( !KIO::NetAccess::del( KURL::fromPathOrURL(path), m_view ))
+    if ( !TDEIO::NetAccess::del( KURL::fromPathOrURL(path), m_view ))
     {
         debug() << "Could not delete!" << endl;
         return -1;
@@ -885,7 +885,7 @@ GenericMediaDevice::addTrackToList( int type, KURL url, int /*size*/ )
 /// Capacity, in kB
 
 bool
-GenericMediaDevice::getCapacity( KIO::filesize_t *total, KIO::filesize_t *available )
+GenericMediaDevice::getCapacity( TDEIO::filesize_t *total, TDEIO::filesize_t *available )
 {
     if( !m_connected || !KURL::fromPathOrURL( m_medium.mountPoint() ).isLocalFile() ) return false;
 
@@ -938,15 +938,15 @@ GenericMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int
     MediaItem *item = static_cast<MediaItem *>(qitem);
     if ( item )
     {
-        KPopupMenu menu( m_view );
+        TDEPopupMenu menu( m_view );
         menu.insertItem( SmallIconSet( Amarok::icon( "playlist" ) ), i18n( "&Load" ), LOAD );
         menu.insertItem( SmallIconSet( Amarok::icon( "1downarrow" ) ), i18n( "&Append to Playlist" ), APPEND );
         menu.insertItem( SmallIconSet( Amarok::icon( "fastforward" ) ), i18n( "&Queue Tracks" ), QUEUE );
         menu.insertSeparator();
         menu.insertItem( SmallIconSet( Amarok::icon( "collection" ) ), i18n( "&Copy Files to Collection..." ), DOWNLOAD );
-        menu.insertItem( SmallIconSet( Amarok::icon( "cdrom_unmount" ) ), i18n( "Burn to CD as Data" ), BURN_DATACD );
+        menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdrom" ) ), i18n( "Burn to CD as Data" ), BURN_DATACD );
         menu.setItemEnabled( BURN_DATACD, K3bExporter::isAvailable() );
-        menu.insertItem( SmallIconSet( Amarok::icon( "cdaudio_unmount" ) ), i18n( "Burn to CD as Audio" ), BURN_AUDIOCD );
+        menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdaudio" ) ), i18n( "Burn to CD as Audio" ), BURN_AUDIOCD );
         menu.setItemEnabled( BURN_AUDIOCD, K3bExporter::isAvailable() );
         menu.insertSeparator();
         menu.insertItem( SmallIconSet( Amarok::icon( "folder" ) ), i18n( "Add Directory" ), DIRECTORY );
@@ -1009,7 +1009,7 @@ GenericMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int
 
     if( isConnected() )
     {
-        KPopupMenu menu( m_view );
+        TDEPopupMenu menu( m_view );
         menu.insertItem( SmallIconSet( Amarok::icon( "folder" ) ), i18n("Add Directory" ), DIRECTORY );
         if ( MediaBrowser::queue()->childCount())
         {
