@@ -24,7 +24,7 @@
 #include "qstringx.h"
 #include "starmanager.h"
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kpixmap.h>
 #include <kpixmapeffect.h>
 #include <kstandarddirs.h>   //locate
@@ -137,7 +137,7 @@ OSDWidget::show() //virtual
     const TQRect newGeometry = determineMetrics( M );
 
     if( m_translucency && !isShown() || !newGeometry.intersects( oldGeometry ) )
-        m_screenshot = TQPixmap(TQPixmap::grabWindow( qt_xrootwin(),
+        m_screenshot = TQPixmap(TQPixmap::grabWindow( tqt_xrootwin(),
                 newGeometry.x(), newGeometry.y(),
                 newGeometry.width(), newGeometry.height() ));
 
@@ -145,7 +145,7 @@ OSDWidget::show() //virtual
     else if ( m_translucency )
     {
         const TQRect unite = oldGeometry.unite( newGeometry );
-        KPixmap pix = TQPixmap(TQPixmap::grabWindow( qt_xrootwin(), unite.x(), unite.y(), unite.width(), unite.height() ));
+        KPixmap pix = TQPixmap(TQPixmap::grabWindow( tqt_xrootwin(), unite.x(), unite.y(), unite.width(), unite.height() ));
 
         TQPoint p = oldGeometry.topLeft() - unite.topLeft();
         bitBlt( &pix, p, &m_screenshot );
@@ -522,13 +522,13 @@ OSDWidget::paintMe()
 
 	// Convert the ARGB pixmap to an ARGB image
 	// NOTE 1: TQPixmap::convertToImage() always converts an ARGB pixmap into an RGB image
-	// NOTE 2: This should eventually make its way into kdelibs or Qt itself,
+	// NOTE 2: This should eventually make its way into tdelibs or Qt itself,
 	// as it would also be useful in applications other than Amarok
 	int w = blendedImage.width();
 	int h = blendedImage.height();
 	Pixmap rawpixmap = m_buffer.handle();
 	XImage *image;
-	image = XGetImage (qt_xdisplay(), rawpixmap, 0, 0, w, h, AllPlanes, XYPixmap);
+	image = XGetImage (tqt_xdisplay(), rawpixmap, 0, 0, w, h, AllPlanes, XYPixmap);
 	for (int y = 0; y < h; ++y) {
 		TQRgb *ls = (TQRgb *)blendedImage.scanLine( y );
 		for (int x = 0; x < w; ++x) {
@@ -604,11 +604,11 @@ OSDWidget::useMoodbar( void )
 
 #include <kcursor.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 namespace Amarok
 {
-    TQImage icon() { return TQImage( KIconLoader().iconPath( "amarok", -KIcon::SizeHuge ) ); }
+    TQImage icon() { return TQImage( TDEIconLoader().iconPath( "amarok", -TDEIcon::SizeHuge ) ); }
 }
 
 OSDPreviewWidget::OSDPreviewWidget( TQWidget *parent )
@@ -808,7 +808,7 @@ Amarok::OSD::show( const MetaBundle &bundle ) //slot
 
             text = osd.namedOptArgs( args );
 
-            // KDE 3.3 rejects \n in the .kcfg file, and KConfig turns \n into \\n, so...
+            // KDE 3.3 rejects \n in the .kcfg file, and TDEConfig turns \n into \\n, so...
             text.replace( "\\n", "\n" );
         }
 
