@@ -27,9 +27,9 @@
 #include "threadmanager.h"
 #include "enginecontroller.h"
 
-#include <kio/job.h>
+#include <tdeio/job.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstdguiitem.h>
 
 #include <tqapplication.h>
@@ -297,16 +297,16 @@ StatusBar::longMessage( const TQString &text, int type )
     {
         case Information:
         case Question:
-            image = KGlobal::iconLoader()->iconPath( "messagebox_info", -KIcon::SizeHuge );
+            image = TDEGlobal::iconLoader()->iconPath( "messagebox_info", -TDEIcon::SizeHuge );
             break;
 
         case Sorry:
         case Warning:
-            image = KGlobal::iconLoader()->iconPath( "messagebox_warning", -KIcon::SizeHuge );
+            image = TDEGlobal::iconLoader()->iconPath( "messagebox_warning", -TDEIcon::SizeHuge );
             break;
 
         case Error:
-            image = KGlobal::iconLoader()->iconPath( "messagebox_critical", -KIcon::SizeHuge );
+            image = TDEGlobal::iconLoader()->iconPath( "messagebox_critical", -TDEIcon::SizeHuge );
             // don't hide error messages.
 //             message->setTimeout( 0 );
             break;
@@ -398,7 +398,7 @@ StatusBar::newProgressOperation( TQObject *owner )
 }
 
 ProgressBar&
-StatusBar::newProgressOperation( KIO::Job *job )
+StatusBar::newProgressOperation( TDEIO::Job *job )
 {
     SHOULD_BE_GUI
 
@@ -407,9 +407,9 @@ StatusBar::newProgressOperation( KIO::Job *job )
 
     if(!allDone())
         toggleProgressWindowButton()->show();
-    connect( job, TQT_SIGNAL(result( KIO::Job* )), TQT_SLOT(endProgressOperation()) );
-    //TODO connect( job, TQT_SIGNAL(infoMessage( KIO::Job *job, const TQString& )), TQT_SLOT() );
-    connect( job, TQT_SIGNAL(percent( KIO::Job*, unsigned long )), TQT_SLOT(setProgress( KIO::Job*, unsigned long )) );
+    connect( job, TQT_SIGNAL(result( TDEIO::Job* )), TQT_SLOT(endProgressOperation()) );
+    //TODO connect( job, TQT_SIGNAL(infoMessage( TDEIO::Job *job, const TQString& )), TQT_SLOT() );
+    connect( job, TQT_SIGNAL(percent( TDEIO::Job*, unsigned long )), TQT_SLOT(setProgress( TDEIO::Job*, unsigned long )) );
 
     return bar;
 }
@@ -418,9 +418,9 @@ void
 StatusBar::endProgressOperation()
 {
     TQObject *owner = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>( sender() )); //HACK deconsting it
-    KIO::Job *job = dynamic_cast<KIO::Job*>( owner );
+    TDEIO::Job *job = dynamic_cast<TDEIO::Job*>( owner );
 
-    //FIXME doesn't seem to work for KIO::DeleteJob, it has it's own error handler and returns no error too
+    //FIXME doesn't seem to work for TDEIO::DeleteJob, it has it's own error handler and returns no error too
     // if you try to delete http urls for instance <- KDE SUCKS!
 
     if( job && job->error() )
@@ -513,7 +513,7 @@ StatusBar::setProgress( int steps )
 }
 
 void
-StatusBar::setProgress( KIO::Job *job, unsigned long percent )
+StatusBar::setProgress( TDEIO::Job *job, unsigned long percent )
 {
     setProgress( static_cast<TQObject*>( job ), percent );
 }
@@ -669,7 +669,7 @@ StatusBar::writeLogFile( const TQString &text )
     TQTextStream stream( &file );
     stream.setEncoding( TQTextStream::UnicodeUTF8 );
 
-    stream << "[" << KGlobal::locale()->formatDateTime( TQDateTime::currentDateTime() ) << "] " << text << endl;
+    stream << "[" << TDEGlobal::locale()->formatDateTime( TQDateTime::currentDateTime() ) << "] " << text << endl;
 }
 
 } //namespace KDE
