@@ -6,6 +6,8 @@
 #ifndef THREADMANAGER_H
 #define THREADMANAGER_H
 
+#include "amarok_export.h"
+
 #include "debug.h"
 #include <tqevent.h>   //baseclass
 #include <tqguardedptr.h>
@@ -77,7 +79,7 @@
 
 
 /// This class is because moc "is really good" (no nested Q_OBJECT classes)
-class JobBase : public TQObject {
+class LIBAMAROK_EXPORT JobBase : public TQObject {
 	Q_OBJECT
 	
 
@@ -89,7 +91,7 @@ protected:
 	bool m_aborted;
 };
 
-class ThreadManager : public TQObject
+class LIBAMAROK_EXPORT ThreadManager : public TQObject
 {
 public:
     class Thread;
